@@ -2,6 +2,9 @@
 I18n utilities.
 """
 
+from __future__ import absolute_import
+from __future__ import unicode_literals
+
 import gettext
 
 
