@@ -13,7 +13,7 @@ import os
 
 from .async_ import AsyncList, Coroutine, Return
 from .common import wraps, setdefault, exc_message
-from .config import IgnoreDevice, FilterMatcher
+from .config import IgnoreDevice, match_config
 from .locale import _
 
 
@@ -119,8 +119,7 @@ class Mounter(object):
     """
 
     def __init__(self, udisks,
-                 mount_options=None,
-                 ignore_device=None,
+                 config=None,
                  prompt=None,
                  browser=None,
                  cache=None):
@@ -128,7 +127,7 @@ class Mounter(object):
         Initialize mounter with the given defaults.
 
         :param udisks: udisks service object. May be a Sniffer or a Daemon.
-        :param FilterMatcher filter: customize mount options and handleability
+        :param list config: list of :class:`DeviceFilter`
         :param callable prompt: retrieve passwords for devices
         :param callable browser: open devices
 
@@ -136,9 +135,7 @@ class Mounter(object):
         If browser is None, browse will not work.
         """
         self.udisks = udisks
-        self._mount_options = mount_options or (lambda device: None)
-        self._ignore_device = ignore_device or FilterMatcher([], None)
-        self._ignore_device._filters += [
+        self._config = (config or []) + [
             IgnoreDevice({'symlinks': '/dev/mapper/docker-*', 'ignore': True}),
             IgnoreDevice({'symlinks': '/dev/disk/by-id/dm-name-docker-*', 'ignore': True}),
             IgnoreDevice({'is_loop': True, 'loop_file': '/*', 'ignore': False}),
@@ -201,7 +198,7 @@ class Mounter(object):
         if device.is_mounted:
             self._log.info(_('not mounting {0}: already mounted', device))
             yield Return(True)
-        options = self._mount_options(device)
+        options = match_config(self._config, device, 'options', None)
         kwargs = dict(options=options)
         self._log.debug(_('mounting {0} with {1}', device, kwargs))
         mount_path = yield device.mount(**kwargs)
@@ -250,6 +247,9 @@ class Mounter(object):
             self._log.error(_('not unlocking {0}: no password prompt', device))
             yield Return(False)
         unlocked = yield self._unlock_from_cache(device)
+        if unlocked:
+            yield Return(True)
+        unlocked = yield self._unlock_from_keyfile(device)
         if unlocked:
             yield Return(True)
         password = yield self._prompt(device)
@@ -276,7 +276,29 @@ class Mounter(object):
         except Exception:
             self._log.debug(_('failed to unlock {0} using cached password', device))
             yield Return(False)
-        self._log.debug(_('unlocked {0} using cached password', device))
+        self._log.info(_('unlocked {0} using cached password', device))
+        yield Return(True)
+
+    @Coroutine.from_generator_function
+    def _unlock_from_keyfile(self, device):
+        if not self.udisks.keyfile_support:
+            yield Return(False)
+        filename = match_config(self._config, device, 'keyfile', None)
+        if filename is None:
+            yield Return(False)
+        try:
+            with open(filename, 'rb') as f:
+                keyfile = f.read()
+        except IOError:
+            self._log.warn(_('configured keyfile for {0} not found', device))
+            yield Return(False)
+        self._log.debug(_('unlocking {0} using keyfile {1}', device, filename))
+        try:
+            yield device.unlock_keyfile(keyfile)
+        except Exception:
+            self._log.debug(_('failed to unlock {0} using keyfile', device))
+            yield Return(False)
+        self._log.info(_('unlocked {0} using keyfile', device))
         yield Return(True)
 
     def _update_cache(self, device, password):
@@ -361,7 +383,7 @@ class Mounter(object):
         :rtype: bool
         """
         success = True
-        if not self.is_handleable(device):
+        if not self.is_automount(device):
             pass
         elif device.is_filesystem:
             if not device.is_mounted:
@@ -650,11 +672,19 @@ class Mounter(object):
             return self.is_handleable(_get_parent(device))
         return not ignored
 
+    def is_automount(self, device):
+        if not self.is_handleable(device):
+            return False
+        return match_config(self._config, device, 'automount', True)
+
+    def _ignore_device(self, device):
+        return match_config(self._config, device, 'ignore', False)
+
     def is_addable(self, device):
         """
         Check if device can be added with ``auto_add``.
         """
-        if not self.is_handleable(device):
+        if not self.is_automount(device):
             return False
         if device.is_filesystem:
             return not device.is_mounted
